@@ -5,6 +5,7 @@ Special thanks to @manitou48 and @jasonkuhrt for their help and support
 
 import requests
 import re
+import json
 
 class Bit:
     def __init__(self, auth_token, device_id):
@@ -16,12 +17,17 @@ class Bit:
         r = requests.post("https://api-http.littlebitscloud.cc/devices/" + self.id + "/output", data={"percent": pct, "duration_ms": dur}, headers=self.headers)
         return r.text
 
-    def iter_input(self):
+    def raw_stream(self):
         #Use this for raw streaming input
-        r = requests.get("https://api-http.littlebitscloud.cc/devices/" + self.id + "/input", headers=self.headers, stream=True)
-        for line in r.iter_lines():
-            #if line: print line
-            yield line   # just fetch one line
-        return
+        for line in requests.get("https://api-http.littlebitscloud.cc/devices/" + self.id + "/input", headers=self.headers, stream=True).iter_lines():
+            if line:
+                yield json.loads(line)
+
+    def stream(self):
+        #Use this for raw streaming input
+        for line in requests.get("https://api-http.littlebitscloud.cc/devices/" + self.id + "/input", headers=self.headers, stream=True).iter_lines():
+            if line:
+                yield int(json.loads(line)["payload"]["percent"])
+
     def input(self):
-        return int(re.match(".*percent.:(\d+)",self.iter_input().next()).group(1))
+        return self.stream().next()
